@@ -10,12 +10,16 @@ def calculate_adam(num_seats, populations):
     and modified divisor. 
     """
 
+    # Record divisors.
+    estimated_divisors = []
+
     # The number of states to apportion to.
     num_states = len(populations)
 
     # The initial divisor
     initial_divisor = sum(populations) / num_seats
-    
+    estimated_divisors.append(initial_divisor)
+
     # The original state quotas respectively.
     initial_quotas = []
     for i, population in enumerate(populations):
@@ -79,6 +83,10 @@ def calculate_adam(num_seats, populations):
             # Reapportion the seats to states given a set of new quotas.
             for i, quota in enumerate(final_quotas):
                 final_fair_shares[i] = math.ceil(quota)
+
+            # Save updated divisor.
+            estimated_divisors.append(modified_divisor)
+
         time_keeper += 1
 
     # If the loop didn't naturally end, return null values.
@@ -87,4 +95,5 @@ def calculate_adam(num_seats, populations):
 
     # Return a list for final fair shares, final quotas and a value for the modified divisor.
     else:
-        return initial_fair_shares, final_fair_shares, initial_quotas, final_quotas, initial_divisor, modified_divisor
+        return initial_fair_shares, final_fair_shares, initial_quotas, final_quotas, initial_divisor, modified_divisor \
+            , estimated_divisors
